@@ -1,6 +1,13 @@
 #' @keywords internal
 #' @export
 pin.data.frame <- function(x, name = NULL, description = NULL, board = NULL, ...) {
+
+  if ("data.table" %in% class(x)) {
+    return(
+      pin.default(x, name = name, description = description, board = board, ...)
+    )
+  }
+
   if (is.null(name)) name <- pin_default_name(deparse(substitute(x)), board)
 
   path <- tempfile()
@@ -28,9 +35,19 @@ pin_load.table <- function(path, ...) {
   rds <- file.path(path, "data.rds")
   csv <- file.path(path, "data.csv")
 
-  if (file.exists(rds)) readRDS(rds)
-  else if (file.exists(csv)) utils::read.csv(csv, stringsAsFactors = FALSE)
+  if (file.exists(rds)) result <- readRDS(rds)
+  else if (file.exists(csv)) result <- utils::read.csv(csv, stringsAsFactors = FALSE)
   else stop("A 'table' pin requires CSV or RDS files.")
+
+  format_tibble(result)
+}
+
+#' @keywords internal
+#' @export
+pin_fetch.table <- function(path, ...) {
+  rds_match <- grepl(".*.rds", path)
+  fetch_all <- identical(getOption("pins.fetch", "auto"), "all")
+  if (any(rds_match) && !fetch_all) path[rds_match] else path
 }
 
 #' @keywords internal
