@@ -4,5 +4,7 @@ pin_load.package <- function(path, ...) {
   files <- dir(path, full.names = TRUE)
   files <- files[!grepl("data\\.txt$", files)]
 
-  get(load(files))
+  result <- get(load(files))
+
+  format_tibble(result)
 }
